==> rapid_router-5.16.7-py2.py3-none-any.whl: game/static/game/js/cow.js <==
'use strict';

var ocargo = ocargo || {};

ocargo.Cow = function(id, data, nodes) {
    this.id = id;
    this.nodes = nodes;
    this.type = data.type;
    this.potentialNodes = [];    // Potential nodes at which a cow could appear
    this.activeNodes = {};       // Actual nodes at which cows will appear during a run.
    for(var i = 0; i < data.potentialCoordinates.length; i++) {
        var coordinate = new ocargo.Coordinate(data.potentialCoordinates[i].x, data.potentialCoordinates[i].y);
        var node = ocargo.Node.findNodeByCoordinate(coordinate, nodes)
        this.potentialNodes.push(ocargo.Node.findNodeByCoordinate(coordinate, nodes));
        var coordinate_str = JSON.stringify(node.coordinate)
        this.activeNodes[coordinate_str] = ocargo.Cow.ACTIVE
    }
};
ocargo.Cow.prototype.reset = function() {

    for (var jsonCoordinate in this.activeNodes) {
        this.activeNodes[jsonCoordinate] = ocargo.Cow.READY;
    }
};

ocargo.Cow.prototype.queueLeaveAnimation = function(model, node) {
    ocargo.animation.appendAnimation({
        type: 'callable',
        functionCall: ocargo.sound.cow,
        description: 'cow sound'
    });
    ocargo.animation.appendAnimation({
        type: 'cow_leave',
        id: this.id,
        coordinate: node.coordinate,
        description: 'Cow leaving'
    });
};

ocargo.Cow.prototype.setInactive = function(model, node) {
    var jsonCoordinate = JSON.stringify(node.coordinate); //get node coordinates
    this.activeNodes[jsonCoordinate] = ocargo.Cow.INACTIVE; //set cow state to inactive
    this.triggerEvent = true;
    this.queueLeaveAnimation(model, node);
};

ocargo.Cow.READY = 'READY';
ocargo.Cow.ACTIVE = 'ACTIVE';
ocargo.Cow.INACTIVE = 'INACTIVE';
ocargo.Cow.WHITE = 'WHITE';
ocargo.Cow.BROWN = 'BROWN';

==> rapid_router-6.4.1-py2.py3-none-any.whl: game/static/game/js/cow.js <==
'use strict';

var ocargo = ocargo || {};

ocargo.Cow = function(id, data, nodes) {
    this.id = id;
    this.nodes = nodes;
    this.type = data.type;
    this.potentialNodes = [];    // Potential nodes at which a cow could appear
    this.activeNodes = {};       // Actual nodes at which cows will appear during a run.
    for(var i = 0; i < data.potentialCoordinates.length; i++) {
        var coordinate = new ocargo.Coordinate(data.potentialCoordinates[i].x, data.potentialCoordinates[i].y);
        var node = ocargo.Node.findNodeByCoordinate(coordinate, nodes)
        this.potentialNodes.push(ocargo.Node.findNodeByCoordinate(coordinate, nodes));
        var coordinate_str = JSON.stringify(node.coordinate)
        this.activeNodes[coordinate_str] = ocargo.Cow.ACTIVE
    }
};
ocargo.Cow.prototype.reset = function() {

    for (var jsonCoordinate in this.activeNodes) {
        this.activeNodes[jsonCoordinate] = ocargo.Cow.READY;
    }
};

ocargo.Cow.prototype.queueLeaveAnimation = function(model, node) {
    ocargo.animation.appendAnimation({
        type: 'callable',
        functionCall: this.type == ocargo.Cow.PIGEON ? ocargo.sound.pigeon : ocargo.sound.cow,
        description: 'animal sound'
    });
    ocargo.animation.appendAnimation({
        type: 'cow_leave',
        id: this.id,
        coordinate: node.coordinate,
        description: 'animal leaving'
    });
};

ocargo.Cow.prototype.setInactive = function(model, node) {
    var jsonCoordinate = JSON.stringify(node.coordinate); //get node coordinates
    this.activeNodes[jsonCoordinate] = ocargo.Cow.INACTIVE; //set cow state to inactive
    this.triggerEvent = true;
    this.queueLeaveAnimation(model, node);
};

ocargo.Cow.READY = 'READY';
ocargo.Cow.ACTIVE = 'ACTIVE';
ocargo.Cow.INACTIVE = 'INACTIVE';
ocargo.Cow.WHITE = 'WHITE';
ocargo.Cow.BROWN = 'BROWN';
ocargo.Cow.PIGEON = 'PIGEON';
